package WebGUI::i18n::Dutch::Asset_DataForm;
use utf8;
our $I18N = {
  10 => {
    'lastUpdated' => '1146835712',
    'message' => 'Van'
  },
  100 => {
    'lastUpdated' => '1149847022',
    'message' => 'Weet u zeker dat u dit tabblad wilt verwijderen?'
  },
  101 => {
    'lastUpdated' => '1146835740',
    'message' => 'Veldnaam'
  },
  102 => {
    'lastUpdated' => '1149847003',
    'message' => 'Wijzig tabblad'
  },
  103 => {
    'lastUpdated' => '1149847013',
    'message' => 'Voeg tabblad toe'
  },
  104 => {
    'lastUpdated' => '1149847032',
    'message' => 'Tabblad'
  },
  '104 description' => {
    'lastUpdated' => '1146835820',
    'message' => 'Wanneer een formulier meerdere tab&#39;s heeft kunt u hier selecteren in welke tab u het veld wilt plaatsen. Indien u niks instelt dan komen alle velden op dezelfde pagina. '
  },
  105 => {
    'lastUpdated' => '1149847046',
    'message' => 'Voeg tabblad toe '
  },
  '105 description' => {
    'lastUpdated' => '1149847054',
    'message' => 'Voeg een tabblad toe aan een dataformulier '
  },
  106 => {
    'lastUpdated' => '1149847063',
    'message' => 'Tabblad sjabloon'
  },
  11 => {
    'lastUpdated' => '1146835866',
    'message' => 'Aan'
  },
  12 => {
    'lastUpdated' => '1146835873',
    'message' => 'CC'
  },
  13 => {
    'lastUpdated' => '1146835880',
    'message' => 'BCC'
  },
  14 => {
    'lastUpdated' => '1146835888',
    'message' => 'Onderwerp'
  },
  16 => {
    'lastUpdated' => '1146835924',
    'message' => 'Bevestigingsbericht'
  },
  '16 description' => {
    'lastUpdated' => '1146835949',
    'message' => 'Dit bericht zal worden weergegeven nadat de gebruiker het dataformulier heeft verstuurd.'
  },
  17 => {
    'lastUpdated' => '1146835974',
    'message' => 'Data e-mailen? '
  },
  18 => {
    'lastUpdated' => '1146835983',
    'message' => 'Terug.'
  },
  19 => {
    'lastUpdated' => '1146835996',
    'message' => 'Weet u zeker dat u dit veld wilt verwijderen?'
  },
  2 => {
    'lastUpdated' => '1146836033',
    'message' => 'Plaats hier uw onderwerp'
  },
  20 => {
    'lastUpdated' => '1146836051',
    'message' => 'Wijzig veld'
  },
  21 => {
    'lastUpdated' => '1146836323',
    'message' => 'Veld ID'
  },
  '21 description' => {
    'lastUpdated' => '1146836341',
    'message' => 'De ID van het veld. Deze ID moet uniek zijn van andere velden in het formulier.'
  },
  22 => {
    'lastUpdated' => '1146836099',
    'message' => 'Status'
  },
  '22 description' => {
    'lastUpdated' => '1146836264',
    'message' => 'Verborgen velden zullen niet zichtbaar zijn voor een gebruiker maar worden wel verzonden in de e-mail. Zichtbare velden worden wel weergegeven maar kunnen niet aangepast worden. Aanpasbare velden kunnen door de gebruiker worden ingevuld en vereiste velden moeten worden ingevuld. Als u kiest voor verborgen of zichtbaar zorg er dan wel voor dat u een standaardwaarde invult. '
  },
  23 => {
    'lastUpdated' => '1146836348',
    'message' => 'Type'
  },
  '23 description' => {
    'lastUpdated' => '1146836394',
    'message' => 'Selecteer het type element. Aan de hand van uw keuze wordt mede bepaald of de ingevulde data, zoals een e-mailadres, juist is. '
  },
  24 => {
    'lastUpdated' => '1146836404',
    'message' => 'Mogelijke waarden'
  },
  '24 description' => {
    'lastUpdated' => '1146836457',
    'message' => 'Dit veld wordt gebruikt voor lijsten zoals een checkboxlist of een selectlist. Vul de gewenste waarden per regel in. '
  },
  25 => {
    'lastUpdated' => '1146836475',
    'message' => 'Standaardwaarde(n)'
  },
  '25 description' => {
    'lastUpdated' => '1146836524',
    'message' => 'Vul, indien gewenst, de standaardwaarde voor dit veld in. Als u een Ja/Nee veld toevoegt type dan &quot;yes&quot; voor ja en &quot;no&quot; voor nee. '
  },
  27 => {
    'lastUpdated' => '1146836533',
    'message' => 'Hoogte'
  },
  '27 description' => {
    'lastUpdated' => '1155907796',
    'message' => 'Vul hier de hoogte in van het veld (in aantal pixels). Deze wordt alleen gebruikt bij textarea&#39;s en HTMLarea&#39;s.'
  },
  28 => {
    'lastUpdated' => '1146836581',
    'message' => 'Optioneel voor textarea&#39;s en HTMLarea&#39;s.'
  },
  29 => {
    'lastUpdated' => '1146836591',
    'message' => 'is vereist'
  },
  3 => {
    'lastUpdated' => '1146836605',
    'message' => 'Bedankt voor uw bericht.'
  },
  4 => {
    'lastUpdated' => '1146836615',
    'message' => 'Verborgen'
  },
  5 => {
    'lastUpdated' => '1146836626',
    'message' => 'Zichtbaar'
  },
  6 => {
    'lastUpdated' => '1146836635',
    'message' => 'Aanpasbaar'
  },
  7 => {
    'lastUpdated' => '1146836680',
    'message' => 'Wijzig dataformulier'
  },
  73 => {
    'lastUpdated' => '1146836908',
    'message' => 'Verstuur'
  },
  74 => {
    'lastUpdated' => '1146836920',
    'message' => 'Data e-mailen?'
  },
  '74 description' => {
    'lastUpdated' => '1207825225',
    'message' => '<p>Als u het dataformulier wilt e-mailen verschijnen er automatisch velden die gebruikt worden voor het e-mailen. Deze velden kunnen niet verwijderd worden maar u kunt ze wel wijzigen.</p><p>Het &quot;aan&quot; veld kan een e-mailadres, een gebruikersnaam of een groep bevatten. Om naar meerdere e-mailadressen te versturen kunt u meerdere adressen achter elkaar typen gescheiden door een komma. <br /> </p>'
  },
  744 => {
    'lastUpdated' => '1146837118',
    'message' => 'Wat wilt u hierna doen?'
  },
  '744 description' => {
    'lastUpdated' => '1166193210',
    'message' => 'Na het aanmaken van het dataformulier kunt u direct velden toevoegen of terug naar de pagina waarop het dataformulier is geplaatst.'
  },
  745 => {
    'lastUpdated' => '1146837162',
    'message' => 'Terug naar de pagina'
  },
  75 => {
    'lastUpdated' => '1146837174',
    'message' => 'Vereist'
  },
  76 => {
    'lastUpdated' => '1146837187',
    'message' => 'Een veld toevoegen '
  },
  '76 description' => {
    'lastUpdated' => '1146837212',
    'message' => 'Exporteer de data van het dataformulier naar een tab gescheiden bestand.'
  },
  77 => {
    'lastUpdated' => '1146837223',
    'message' => 'Veldnaam'
  },
  '77 description' => {
    'lastUpdated' => '1146837261',
    'message' => 'Dit is de naam van het veld die wordt weergegeven voor het element.'
  },
  79 => {
    'lastUpdated' => '1146837277',
    'message' => 'Voetnoot'
  },
  '79 description' => {
    'lastUpdated' => '1146837338',
    'message' => 'Dit is een extra veld waar uitgebreidere informatie over het in te vullen veld kan komen te staan. '
  },
  8 => {
    'lastUpdated' => '1146837347',
    'message' => 'Breedte'
  },
  '8 description' => {
    'lastUpdated' => '1155907821',
    'message' => 'Dit is de breedte van het veld in pixels. '
  },
  80 => {
    'lastUpdated' => '1146837570',
    'message' => 'Email sjabloon'
  },
  '80 description' => {
    'lastUpdated' => '1146837642',
    'message' => 'Selecteer een sjabloon voor de data die per e-mail verzonden wordt.'
  },
  81 => {
    'lastUpdated' => '1146837664',
    'message' => 'Bevestingings sjabloon'
  },
  '81 description' => {
    'lastUpdated' => '1207916976',
    'message' => 'Selecteer een sjabloon voor het weergeven van de bevestiging van de verstuurde data. '
  },
  82 => {
    'lastUpdated' => '1146837802',
    'message' => 'Dataformulier sjabloon'
  },
  '82 description' => {
    'lastUpdated' => '1146837829',
    'message' => 'Selecteer een sjabloon voor het dataformulier '
  },
  84 => {
    'lastUpdated' => '1146837857',
    'message' => 'Exporteer tab gescheiden'
  },
  85 => {
    'lastUpdated' => '1146837877',
    'message' => '&eacute;&eacute;n per regel.'
  },
  86 => {
    'lastUpdated' => '1146837901',
    'message' => 'Laat lijst zien'
  },
  '86 description' => {
    'lastUpdated' => '1146837942',
    'message' => 'Laat alle ingevulde data zien.'
  },
  87 => {
    'lastUpdated' => '1146837961',
    'message' => 'Lijst sjabloon'
  },
  '87 description' => {
    'lastUpdated' => '1146838054',
    'message' => 'Selecteer een template die gebruikt wordt voor het weergeven van alle ingevulde velden in een lijst.'
  },
  88 => {
    'lastUpdated' => '1146838071',
    'message' => 'Dataformulier lijst sjabloon'
  },
  90 => {
    'lastUpdated' => '1146838128',
    'message' => 'Verwijder deze aanmelding'
  },
  91 => {
    'lastUpdated' => '1146838140',
    'message' => 'Verwijder alle data'
  },
  'Delete entry confirmation' => {
    'lastUpdated' => '1146838164',
    'message' => 'Weet u zeker dat u alle ingevulde data van het dataformulier wilt verwijderen? '
  },
  'Entry ID' => {
    'lastUpdated' => '1231520556',
    'message' => 'ID inzending'
  },
  'Field Position' => {
    'lastUpdated' => '1146838183',
    'message' => 'Veld positie'
  },
  'Field Position description' => {
    'lastUpdated' => '1146838288',
    'message' => 'U kunt de positie van het veld instellen zodat deze gelijk op de juiste plek wordt neergezet. '
  },
  'Submission Date' => {
    'lastUpdated' => '1231520534',
    'message' => 'Datum inzending'
  },
  'Use Default Rich Editor' => {
    'lastUpdated' => '1242725327',
    'message' => 'Gebruik standaard Rich Editor'
  },
  'acknowledgement var desc' => {
    'lastUpdated' => '1207834587',
    'message' => 'Dit is de bevestiging die de gebruiker krijgt na het versturen van het Dataformulier.'
  },
  'acknowlegementTemplateId' => {
    'lastUpdated' => '1166193297',
    'message' => 'Dit is het ID van het sjabloon voor het bevestigingsbericht.'
  },
  'add entry' => {
    'lastUpdated' => '1297774445',
    'message' => 'Voer waarde in'
  },
  'addField.label' => {
    'lastUpdated' => '1149845600',
    'message' => 'De standaard tekst voor de addField.url variabele. '
  },
  'addField.url' => {
    'lastUpdated' => '1149845623',
    'message' => 'De url om een nieuw veld aan het formulier toe te voegen.'
  },
  'addTab.label' => {
    'lastUpdated' => '1149845647',
    'message' => 'De standaard tekst voor de addTab.url variabele. '
  },
  'addTab.url' => {
    'lastUpdated' => '1149847091',
    'message' => 'De url voor het toevoegen van een nieuw tabblad aan het formulier.'
  },
  'assetName' => {
    'lastUpdated' => '1146838304',
    'message' => 'Dataformulier'
  },
  'back.label' => {
    'lastUpdated' => '1149845699',
    'message' => 'De standaard tekst voor de back.url variabele.'
  },
  'back.url' => {
    'lastUpdated' => '1149845725',
    'message' => 'De url om terug te keren naar de standaard pagina van het formulier. '
  },
  'canEdit' => {
    'lastUpdated' => '1149845773',
    'message' => 'Een variabele die bepaalt of de gebruiker rechten heeft om het dataformulier te wijzigen.'
  },
  'canViewEntries' => {
    'lastUpdated' => '1199098812',
    'message' => 'Deze sjabloon variabele is waar wanneer de huidige gebruiker is toegestaan de lijst met ingezonden formulieren van het DataForm te bekijken.'
  },
  'confirm delete all' => {
    'lastUpdated' => '1155554333',
    'message' => 'Weet u zeker dat alle data van dit DataForm permanent verwijderd moeten worden? '
  },
  'confirm delete one' => {
    'lastUpdated' => '1155554314',
    'message' => 'Weet u zeker dat u deze invoer permanent wilt verwijderen?'
  },
  'data form' => {
    'lastUpdated' => '1146838315',
    'message' => 'Dataformulier'
  },
  'data form asset template variables body' => {
    'lastUpdated' => '1166193331',
    'message' => 'Ieder Asset heeft bepaalde variabelen binnen de templates betreffende de eigenschappen van een Asset. Sommige zullen bruikbaar zijn, anderen niet.'
  },
  'data form asset template variables title' => {
    'lastUpdated' => '1166193351',
    'message' => 'Dataformulier sjabloon variabelen'
  },
  'data list' => {
    'lastUpdated' => '1146838326',
    'message' => 'Data lijst'
  },
  'date' => {
    'lastUpdated' => '1149845853',
    'message' => 'De datum waarop de ingevulde data is toegevoegd of gewijzigd.'
  },
  'defaultView' => {
    'lastUpdated' => '1146838343',
    'message' => 'Standaard weergave'
  },
  'defaultView description' => {
    'lastUpdated' => '1166193361',
    'message' => 'Selecteer de standaardweergave van het dataformulier. U kunt kiezen uit het in te vullen formulier of een overzicht van de al ingevulde velden. Als u kiest voor deze laatste optie dan wordt er geen bevestigingsbericht weergegeven als u data toevoegt aan het formulier. '
  },
  'defaultView var desc' => {
    'lastUpdated' => '1189335887',
    'message' => 'Dit is waar als het DataForm object standaard is ingesteld op Lijstweergave, in plaats van op Formulierweergave.'
  },
  'delete file' => {
    'lastUpdated' => '1166193373',
    'message' => 'Verwijder bestand'
  },
  'delete.label' => {
    'lastUpdated' => '1166193502',
    'message' => 'De standaard tekst voor de variabele delete.url.'
  },
  'delete.url' => {
    'lastUpdated' => '1166193556',
    'message' => 'De variabele voor de URL waarmee een ingevuld formulier verwijderd kan worden.'
  },
  'deleteAllEntries.label' => {
    'lastUpdated' => '1155554284',
    'message' => 'Het standaard label van de deleteAllEntrie.url variabele.'
  },
  'deleteAllEntries.url' => {
    'lastUpdated' => '1155554376',
    'message' => 'Een URL waar de gebruiker alle ingevoerde data in het DataForm kan verwijderen.'
  },
  'edit.url' => {
    'lastUpdated' => '1149845888',
    'message' => 'De url om de ingevulde data te wijzigen.'
  },
  'editField extras label' => {
    'lastUpdated' => '1146838478',
    'message' => 'Extras'
  },
  'editField extras label description' => {
    'lastUpdated' => '1146838616',
    'message' => 'Hier kunt u extra tags toevoegen aan het veld. Zoals bijvoorbeeld class=&quot;mijnclass&quot; '
  },
  'editField vertical label' => {
    'lastUpdated' => '1146839028',
    'message' => 'Verticaal uitlijnen'
  },
  'editField vertical label description' => {
    'lastUpdated' => '1146839281',
    'message' => 'Hier kunt u instellen of u de checklists en radiobuttons horizontaal of verticaal wilt uitlijnen.'
  },
  'editField vertical subtext' => {
    'lastUpdated' => '1146839327',
    'message' => 'Dit veld wordt alleen gebruikt voor radiobuttons en checklists. '
  },
  'editForm useCaptcha description' => {
    'lastUpdated' => '1213704195',
    'message' => 'Als dit op ja staat vereist het DataForm een CAPTCHA voor bezoekers. Geregistreerde gebruikers zullen deze niet zien.'
  },
  'editForm useCaptcha label' => {
    'lastUpdated' => '1213705295',
    'message' => 'Captcha gebruiken voor bezoekers?'
  },
  'editForm workflowIdAddEntry description' => {
    'lastUpdated' => '1225915438',
    'message' => 'Workflow die aangezet moet worden wanneer een toevoeging aan het DataFormulier gedaan is.'
  },
  'editForm workflowIdAddEntry label' => {
    'lastUpdated' => '1225915459',
    'message' => 'Voeg invoer Workflow toe'
  },
  'emailTemplateId' => {
    'lastUpdated' => '1166193446',
    'message' => 'Het ID van het Email sjabloon.'
  },
  'entryId' => {
    'lastUpdated' => '1149846002',
    'message' => 'Het id van het huidige ingevulde formulier. Deze variabele bestaat alleen wanneer de gebruiker het dataformulier kan wijzigen. '
  },
  'entryList.label' => {
    'lastUpdated' => '1149846035',
    'message' => 'De standaard tekst voor de entryList.url variabele.'
  },
  'entryList.url' => {
    'lastUpdated' => '1149846079',
    'message' => 'De url naar de pagina met een overzicht van alle ingevulde dataformulieren.'
  },
  'epoch' => {
    'lastUpdated' => '1149846711',
    'message' => 'De datum dat de data is verstuurd of gewijzigd als een epoch datum. '
  },
  'error captcha' => {
    'lastUpdated' => '1213704233',
    'message' => 'Captcha niet correct ingevoerd. Probeer het alstublieft opnieuw.'
  },
  'error.message' => {
    'lastUpdated' => '1149846737',
    'message' => 'Een foutmelding met wat de gebruiker verkeerd gedaan kan hebben.'
  },
  'error_loop' => {
    'lastUpdated' => '1149846773',
    'message' => 'Een loop met foutmeldingen. Bijvoorbeeld als iemand een verplicht veld niet invult.'
  },
  'export.tab.label' => {
    'lastUpdated' => '1149846793',
    'message' => 'De standaard tekst voor de export.tab.url variabele.'
  },
  'export.tab.url' => {
    'lastUpdated' => '1149846830',
    'message' => 'De url voor het exporteren van de ingevulde data als een tab gescheiden bestand.'
  },
  'field.controls' => {
    'lastUpdated' => '1149846863',
    'message' => 'WebGUI&#39;s administratieve functies voor het wijzigen van dit veld.'
  },
  'field.form' => {
    'lastUpdated' => '1149846883',
    'message' => 'Het form element voor dit veld.'
  },
  'field.id' => {
    'lastUpdated' => '1149846936',
    'message' => 'Een uniek nummer waar het veld mee wordt opgeslagen in de database.'
  },
  'field.inTab' => {
    'lastUpdated' => '1207834292',
    'message' => 'Bepaalt of het veld zich in een tabblad bevindt. '
  },
  'field.isDisplayed' => {
    'lastUpdated' => '1207834384',
    'message' => 'Bepaalt of het veld weergegeven moet worden. '
  },
  'field.isHidden' => {
    'lastUpdated' => '1207834361',
    'message' => 'Bepaalt of het veld verborgen moet zijn.'
  },
  'field.isMailField' => {
    'lastUpdated' => '1207834461',
    'message' => 'Bepaalt of het veld alleen gebruikt wordt om het e-mailbericht mee te versturen.'
  },
  'field.isRequired' => {
    'lastUpdated' => '1207834303',
    'message' => 'Bepaalt of het veld vereist is.'
  },
  'field.label' => {
    'lastUpdated' => '1149847983',
    'message' => 'De tekst voor het veld.'
  },
  'field.name' => {
    'lastUpdated' => '1149848014',
    'message' => 'De naam van het veld.'
  },
  'field.subtext' => {
    'lastUpdated' => '1149848053',
    'message' => 'Een omschrijving van het veld zodat de gebruiker weet wat er ingevuld moet worden.'
  },
  'field.tid' => {
    'lastUpdated' => '1149848074',
    'message' => 'Het id van het tabblad waar het veld zich in bevindt.'
  },
  'field.type' => {
    'lastUpdated' => '1149848138',
    'message' => 'Het type data wat in het veld ingevoerd kan worden.'
  },
  'field.value' => {
    'lastUpdated' => '1149848170',
    'message' => 'De waarden van het veld. Als er nog niks is ingevuld dan wordt de standaardwaarde ingevuld.'
  },
  'field_loop' => {
    'lastUpdated' => '1166193571',
    'message' => 'Een loop met alle velden. Buiten de loop kunnen alle velden ook benaderd worden. Hiervoor kunnen de volgende variabelen gebruikt worden. Om ze aan te roepen gebruik field.noloop.<em>veldnaam.property</em>. Waarbij de veldnaam dus gebruikt wordt en voor de property kunnen de variabelen gebruikt worden. Voorbeeld: field.noloop.naam.form geeft het veld naam weer en field.noloop.naam.isRequired geeft aan of het veld verplicht is of niet. '
  },
  'form.end' => {
    'lastUpdated' => '1149848502',
    'message' => 'Het einde van het formulier. '
  },
  'form.save' => {
    'lastUpdated' => '1149848523',
    'message' => 'De knop voor het versturen van de ingevulde data.'
  },
  'form.send' => {
    'lastUpdated' => '1149848574',
    'message' => 'Een knop met de vertaling van het woord, afhankelijk van de taal van de gebruiker ingesteld in het profiel, &quot;Verstuur&quot;.'
  },
  'form.start' => {
    'lastUpdated' => '1149848585',
    'message' => 'Het begin van het formulier.'
  },
  'go to form' => {
    'lastUpdated' => '1146839343',
    'message' => 'Ga naar het formulier'
  },
  'group to view entries' => {
    'lastUpdated' => '1149000200',
    'message' => 'Welke groep mag de ingevulde data zien? '
  },
  'group to view entries description' => {
    'lastUpdated' => '1149000169',
    'message' => 'Deze groep mag de ingevulde data bekijken.'
  },
  'groupToViewEntries' => {
    'lastUpdated' => '1166193628',
    'message' => 'Het ID van de groep die alle ingevulde formulieren mogen bekijken wanneer het formulier in de standaard weergave is.'
  },
  'hasEntries' => {
    'lastUpdated' => '1155554463',
    'message' => 'Het aantal ingevoerde objecten in dit DataForm.'
  },
  'help record.noloop' => {
    'lastUpdated' => '1253789921',
    'message' => 'De waarde van een veld kan op naam opgevraagd worden, bijvoorbeeld record.noloop.subject'
  },
  'helpvar form.captcha' => {
    'lastUpdated' => '1213704958',
    'message' => 'Het invoer veld en de afbeelding voor de Captcha'
  },
  'helpvar useCaptcha' => {
    'lastUpdated' => '1221145075',
    'message' => 'Deze variabele is waar als de Captcha getoond moet worden.'
  },
  'htmlAreaRichEditor' => {
    'lastUpdated' => '1242725514',
    'message' => 'HTML Area element Rich Editor'
  },
  'htmlAreaRichEditor description' => {
    'lastUpdated' => '1242725480',
    'message' => 'Selecteer de Rich Editor die u wilt gebruiken voor HTML Area elementen. De standaard Rich Editor is dezelfde als diegene geselecteerd bij de instellingen.'
  },
  'ipAddress' => {
    'lastUpdated' => '1149848608',
    'message' => 'Het ipadres van de gebruiker die de data heeft ingevuld. '
  },
  'javascript.confirmation.deleteAll' => {
    'lastUpdated' => '1155554527',
    'message' => 'Dit is een javascript dat een internationaal popup bericht laat verschijnen. Het bericht bevestigt dat alle ingevoerde velden verwijderd zijn.'
  },
  'javascript.confirmation.deleteOne' => {
    'lastUpdated' => '1166193661',
    'message' => 'De vertaalde tekst voor de Javascript popup bij het verwijderen van een ingevuld formulier.'
  },
  'listTemplateId' => {
    'lastUpdated' => '1166193684',
    'message' => 'De ID van het lijst sjabloon.'
  },
  'mail attachments' => {
    'lastUpdated' => '1166193702',
    'message' => 'Bijlagen mailen?'
  },
  'mail attachments description' => {
    'lastUpdated' => '1166193773',
    'message' => 'Deze functie moet gebruikt worden in combinatie met de optie "Data emailen". Als u deze optie inschakelt dan worden ook de bijlagen die eventueel aan het dataformulier zijn toegevoegd gemaild.'
  },
  'mailAttachments' => {
    'lastUpdated' => '1166193890',
    'message' => 'mailBijlagen staat op "Ja" als het dataformulier bijlagen moet emailen.'
  },
  'mailData' => {
    'lastUpdated' => '1166193935',
    'message' => 'dataEmailen staat op "Ja" als het dataformulier email moet versturen als een formulier is ingevuld.'
  },
  'no tab' => {
    'lastUpdated' => '1149000211',
    'message' => 'Geen tabbladen'
  },
  'record.data.isMailField' => {
    'lastUpdated' => '1207834442',
    'message' => 'Bepaalt of het veld bestaat voor het e-mailbericht of het dataformulier.'
  },
  'record.data.label' => {
    'lastUpdated' => '1149851693',
    'message' => 'De datum van het veld.'
  },
  'record.data.name' => {
    'lastUpdated' => '1149851722',
    'message' => 'De naam van het veld (zonder leestekens)'
  },
  'record.data.value' => {
    'lastUpdated' => '1149851762',
    'message' => 'De waarde ingevuld door de gebruiker voor dit veld in dit formulier. '
  },
  'record.data_loop' => {
    'lastUpdated' => '1149852773',
    'message' => 'Een loop met de ingevulde data van de gebruiker voor ieder veld in het dataformulier.'
  },
  'record.delete.icon' => {
    'lastUpdated' => '1149852829',
    'message' => 'Een icoon met bijbehorende url voor het verwijderen van dit formulier.'
  },
  'record.delete.url' => {
    'lastUpdated' => '1149852846',
    'message' => 'De url voor het verwijderen van dit formulier.'
  },
  'record.edit.icon' => {
    'lastUpdated' => '1149852875',
    'message' => 'Een icoon met bijbehorende url voor het wijzigen van dit formulier. '
  },
  'record.edit.url' => {
    'lastUpdated' => '1149852891',
    'message' => 'De url voor het wijzigen van dit formulier.'
  },
  'record.entryId' => {
    'lastUpdated' => '1149854178',
    'message' => 'Een uniek nummer voor dit formulier. '
  },
  'record.ipAddress' => {
    'lastUpdated' => '1149855361',
    'message' => 'Het ipadres van de gebruiker die het formulier ingevuld heeft.'
  },
  'record.submissionDate.epoch' => {
    'lastUpdated' => '1149856165',
    'message' => 'De epoch datum van dit formulier.'
  },
  'record.submissionDate.human' => {
    'lastUpdated' => '1149856452',
    'message' => 'De datum weergegeven in het formaat zoals de gebruiker dit heeft ingesteld in het profiel.'
  },
  'record.userId' => {
    'lastUpdated' => '1149856479',
    'message' => 'Het unieke nummer van de gebruiker die het formulier heeft ingevuld.'
  },
  'record.username' => {
    'lastUpdated' => '1149856504',
    'message' => 'De gebruikersnaam van de gebruiker die het formulier heeft ingevuld.'
  },
  'record_data_type' => {
    'lastUpdated' => '1199098836',
    'message' => 'Het data type wat bij dit veld hoort.'
  },
  'record_loop' => {
    'lastUpdated' => '1149856557',
    'message' => 'Een loop met alle velden van dit dataformulier '
  },
  'store data' => {
    'lastUpdated' => '1213704993',
    'message' => 'Sla de data op'
  },
  'store data description' => {
    'lastUpdated' => '1213705038',
    'message' => 'Dit bepaalt of de ingevoerde data wel of niet opgeslagen moet worden.'
  },
  'tab.controls' => {
    'lastUpdated' => '1149856984',
    'message' => 'De icoontjes voor het wijzigen van dit tabblad.'
  },
  'tab.end' => {
    'lastUpdated' => '1149857004',
    'message' => 'Code voor het eindigen van het tabblad.'
  },
  'tab.field.controls' => {
    'lastUpdated' => '1149857027',
    'message' => 'WebGUI&#39;s administratieve functies voor het wijzigen van dit veld.'
  },
  'tab.field.form' => {
    'lastUpdated' => '1149858288',
    'message' => 'Het formelement voor dit veld.'
  },
  'tab.field.isDisplayed' => {
    'lastUpdated' => '1207834495',
    'message' => 'Bepaalt of het veld wordt weergegeven.'
  },
  'tab.field.isHidden' => {
    'lastUpdated' => '1207834422',
    'message' => 'Bepaalt of het veld verborgen wordt.'
  },
  'tab.field.isMailField' => {
    'lastUpdated' => '1207834478',
    'message' => 'Bepaalt of het veld wordt gebruikt voor het verzenden van het e-mailbericht. '
  },
  'tab.field.isRequired' => {
    'lastUpdated' => '1207834337',
    'message' => 'Bepaalt of het veld vereist is.'
  },
  'tab.field.label' => {
    'lastUpdated' => '1149857183',
    'message' => 'De standaard tekst voor dit veld. '
  },
  'tab.field.name' => {
    'lastUpdated' => '1149857193',
    'message' => 'De naam van het veld.'
  },
  'tab.field.subtext' => {
    'lastUpdated' => '1149857929',
    'message' => 'Een omschrijving van het veld zodat gebruikers weten ze moeten invullen.'
  },
  'tab.field.tid' => {
    'lastUpdated' => '1149857951',
    'message' => 'Het unieke nummer van het tabblad waar het veld zich in bevindt.'
  },
  'tab.field.value' => {
    'lastUpdated' => '1149857983',
    'message' => 'De waarde van dit veld. Als deze leeg is wordt de standaardwaarde ingevuld.'
  },
  'tab.field_loop' => {
    'lastUpdated' => '1149858038',
    'message' => 'Een loop met alle velden voor dit tabblad. Zie de onderliggende field_loop omschrijving om de beschikbare variabelen te bekijken.'
  },
  'tab.init' => {
    'lastUpdated' => '1149858061',
    'message' => 'Code om ervoor te zorgen dat de tabbladen werken.'
  },
  'tab.label' => {
    'lastUpdated' => '1149858089',
    'message' => 'De tekst voor dit tabblad.'
  },
  'tab.sequence' => {
    'lastUpdated' => '1207835305',
    'message' => 'Een nummer dat aangeeft welk tabblad dit is.'
  },
  'tab.start' => {
    'lastUpdated' => '1149858137',
    'message' => 'Code om het tabblad te starten. '
  },
  'tab.subtext' => {
    'lastUpdated' => '1166193951',
    'message' => 'Een omschrijving van het tabblad.'
  },
  'tab.tid' => {
    'lastUpdated' => '1149858167',
    'message' => 'het unieke nummer van dit tabblad. '
  },
  'tab_loop' => {
    'lastUpdated' => '1207835263',
    'message' => 'Een loop met alle informatie over het tabblad die gedefineerd is voor het dataformulier.'
  },
  'template captcha label' => {
    'lastUpdated' => '1221145096',
    'message' => 'Anti spamcode'
  },
  'templateId' => {
    'lastUpdated' => '1166193979',
    'message' => 'Het ID van het dataformulier sjabloon.'
  },
  'userId' => {
    'lastUpdated' => '1149858260',
    'message' => 'Het unieke nummer van de gebruiker die de data heeft ingevuld.'
  },
  'username' => {
    'lastUpdated' => '1149858249',
    'message' => 'De gebruikersnaam van diegene die de data heeft ingevuld.'
  }
}
;

1;
